"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const Schema_1 = require('./Schema');
const templateHelpers_1 = require('./templateHelpers');
const glob = require('glob');
const mkdirp = require('mkdirp');
/**
 * Recursively create the output directory if it does not exist already
 * @param directory {string} the output directory to create
 */
function createOutputDir(directory) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!directory) {
            return Promise.resolve();
        }
        return new Promise((resolve, reject) => {
            mkdirp(directory, (err) => {
                return err ? reject(err) : resolve();
            });
        });
    });
}
/**
 * Wrapper around glob to promisify it
 * @param globPattern {string} the glob pattern to look for
 * @returns {Promise<Array<string>>} any array of files which match the specified glob pattern
 */
function promisedGlob(globPattern) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            glob(globPattern, { realpath: true }, (err, files) => {
                return err ? reject(err) : resolve(files);
            });
        });
    });
}
module.exports = function (globPattern, outputDirectory) {
    return __awaiter(this, void 0, void 0, function* () {
        const files = yield Promise.all([
            promisedGlob(globPattern),
            createOutputDir(outputDirectory)
        ])
            .then(results => results[0]);
        // if no files, nothing to do
        if (!files || files.length < 1) {
            console.info('No JSON schema files found');
            return Promise.resolve([]);
        }
        const schemas = files.map((file) => new Schema_1.Schema(require(file)));
        return Promise.all(schemas.map((schema) => templateHelpers_1.generateInterfaceFile(schema, schemas, outputDirectory)))
            .then((fileNames) => {
            // remove any empty files
            return fileNames.filter(filename => !!filename);
        });
    });
};
